import sqlite3
import urlparse
import urllib
import os.path
import datetime

banshee   = sqlite3.connect(os.path.expanduser('~/.config/banshee-1/banshee.db'))
gogglesmm = sqlite3.connect(os.path.expanduser('~/.local/share/gogglesmm/goggles.db'))
bc = banshee.cursor()
gc = gogglesmm.cursor()

bc.execute('SELECT Uri, PlayCount,SkipCount, Rating, Score, LastPlayedStamp FROM CoreTracks')
for row in bc:
  rating    = row[3] * 51
  playcount = row[1]
  url       = urlparse.urlsplit(row[0])
  if url.scheme == 'file' and (rating>0 or playcount>0) :

    # Get path and filename
    path = urllib.unquote(url.path)
    dir,file = os.path.split(path)

    # Get lastplayed date
    if row[5]:  
      playdate    = long(row[5])
      playdate_ns = playdate*1000000000  
    else:
      playdate    = 0
      playdate_ns = 0

    # find track in gogglesmm
    args = (dir,file,)
    gc.execute('SELECT tracks.id FROM tracks,pathlist WHERE tracks.path == pathlist.id AND pathlist.name = ? AND tracks.mrl = ?',args)
    id = gc.fetchone()

    # Update track in gogglesmm if found 
    if id:
      print 'Update playcount %d, rating %d, playdate %s for \'%s/%s\'' % (playcount,row[3],datetime.datetime.fromtimestamp(playdate),dir,file)
      args = (playcount,rating,playdate_ns,id[0],)
      gc.execute('UPDATE tracks SET playcount = playcount + ?, rating = ?, playdate = max(playdate,?) WHERE tracks.id == ?',args)
      gogglesmm.commit()
    else:
      print 'Not found in database %s/%s' % (dir,file)

gogglesmm.close();
banshee.close();



import sqlite3
import urlparse
import urllib
import os.path
import datetime

v12       = sqlite3.connect(os.path.expanduser('~/.goggles/goggles.db'))
gogglesmm = sqlite3.connect(os.path.expanduser('~/.local/share/gogglesmm/goggles.db'))
vc = v12.cursor()
vcp = v12.cursor()
gc = gogglesmm.cursor()

vc.execute('SELECT path,mrl,playcount,playdate FROM tracks')
for row in vc:
  playcount = row[2]
  if playcount > 0:
    playdate  = row[3]
    path      = ""
    file			= row[1]

    if row[0]>0:
      vcp.execute("SELECT name FROM directories WHERE (select path || id || '/' from directories WHERE id = ? ) like path || id || '/%' order by path;",(row[0],))
      components = []
      for p in vcp:
        components.append(p[0])
      path = os.path.join(*components)
    else:
      path,file = os.path.split(mrl)

    gc.execute('SELECT tracks.id FROM tracks,pathlist WHERE tracks.path == pathlist.id AND pathlist.name = ? AND tracks.mrl = ?',(path,file,))
    id = gc.fetchone()
    if id:
      print 'Update playcount %d, playdate %s for \'%s/%s\'' % (playcount,datetime.datetime.fromtimestamp(playdate/1000000000),path,file)
      gc.execute('UPDATE tracks SET playcount = playcount + ?, playdate = max(playdate,?) WHERE tracks.id == ?',(playcount,playdate,id[0],))
      gogglesmm.commit()
    else:
      print 'Not found in database %s/%s' % (path,file)

gogglesmm.close();
v12.close();



import sqlite3
import urlparse
import urllib
import os.path
import datetime
import codecs

v12       = sqlite3.connect(os.path.expanduser('~/.goggles/goggles.db'))
gogglesmm = sqlite3.connect(os.path.expanduser('~/.local/share/gogglesmm/goggles.db'))


vc  = v12.cursor()
vct = v12.cursor()
vcp = v12.cursor()
gc  = gogglesmm.cursor()

# Look up path in old db
def lookup_path(path,mrl):
  if path>0:
    vcp.execute("SELECT name FROM directories WHERE (select path || id || '/' from directories WHERE id = ? ) like path || id || '/%' order by path;",(path,))
    components = []
    for p in vcp:
      components.append(p[0])
    path = os.path.join(*components)
    return path,mrl
  else:
    path,file = os.path.split(mrl)
    return path,file

# Transfer streams
vc.execute('SELECT url,description,genres.name,bitrate,rating FROM streams,genres WHERE streams.genre == genres.id')
for row in vc:
  
  # Insert Tag
  gc.execute('SELECT id FROM tags WHERE name == ?',(row[2],))
  id = gc.fetchone()  
  if not id:
    gc.execute('INSERT INTO tags VALUES ( NULL, ?)',(row[2],))
    tag = gc.lastrowid
  else:
    tag = id[0]

  # Insert Stream
  gc.execute('INSERT INTO streams VALUES ( NULL, ?, ?, ?, ? ,?)',(row[0],row[1],tag,row[3],row[4],))
  gogglesmm.commit()


# Export Play Lists
vc.execute('SELECT id, name FROM playlists')
for playlist in vc:

  filename = '%d_%s.m3u' % (playlist[0],playlist[1])

  print 'Exporting playlist %s to %s' % (playlist[1],filename)
  m3u = codecs.open(filename, "w", "utf-8")

  vct.execute('SELECT path, mrl FROM playlist_tracks, tracks WHERE playlist_tracks.track == tracks.id AND playlist_tracks.playlist == ? ORDER BY playlist_tracks.queue',(playlist[0],))
  for track in vct:
    path,file = lookup_path(track[0],track[1])
    m3u.write("%s\n" % os.path.join(path,file))    
    
  m3u.close()

gogglesmm.close();
v12.close();
